# Dashboards Settings
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/dashboards-settings?version=CLOUD#overview)
  * [Predefined Dashboards](https://help.sap.com/docs/leanix/ea/dashboards-settings?version=CLOUD#predefined-dashboards)
  * [Default Dashboard](https://help.sap.com/docs/leanix/ea/dashboards-settings?version=CLOUD#default-dashboard)
  * [External Content](https://help.sap.com/docs/leanix/ea/dashboards-settings?version=CLOUD#external-content)
  * [Dashboard Templates](https://help.sap.com/docs/leanix/ea/dashboards-settings?version=CLOUD#dashboard-templates)


Configure dashboard settings and add specific dashboards to the workspace.
